/**
 * Updates the emulator configuration to show the
 * image using the given properties when one opens the Camera app.
 *
 * @this {AndroidDriver}
 * @param {string} sdkRoot ADB SDK root folder path
 * @returns {Promise<boolean>} If emulator services restart is needed
 * to load the updated config or false if the current config is already up to date
 * or does not need to be updated
 */
export function prepareEmulatorForImageInjection(this: import("../driver").AndroidDriver, sdkRoot: string): Promise<boolean>;
/**
 * Updates the emulator configuration to show the given
 * image on the foreground when one opens the Camera app.
 * It is expected that the rear camera of the emulator is
 * configured to show VirtualScene for this feature to work.
 * It is expected that the Virtual Scene posters config is
 * already prepared and loaded either manually or using the
 * `injectedImageProperties` capability.
 *
 * @this {AndroidDriver}
 * @param {string} payload Base64-encoded payload of a .png image to be injected
 * @returns {Promise<void>}
 */
export function mobileInjectEmulatorCameraImage(this: import("../driver").AndroidDriver, payload: string): Promise<void>;
export type ADB = import("appium-adb").ADB;
export type AndroidDriver = import("../driver").AndroidDriver;
//# sourceMappingURL=image-injection.d.ts.map